==> qt5-charts-debuginfo-5.9.2-1.tar.xz: usr/src/debug/qt5-charts-5.9.2-1/examples/charts/candlestickchart/.rcc/qrc_candlestickdata.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-charts/qt5-charts-5.9.2-1.x86_64/src/qtcharts-opensource-src-5.9.2/examples/charts/candlestickchart/acme_data.txt
  0x0,0x0,0x3,0xec,
  0x23,
  0x20,0x41,0x63,0x6d,0x65,0x20,0x4c,0x74,0x64,0x20,0x48,0x69,0x73,0x74,0x6f,0x72,
  0x69,0x63,0x61,0x6c,0x20,0x44,0x61,0x74,0x61,0x20,0x28,0x4a,0x75,0x6c,0x79,0x20,
  0x32,0x30,0x31,0x35,0x29,0xa,0x23,0x20,0x74,0x69,0x6d,0x65,0x73,0x74,0x61,0x6d,
  0x70,0x2c,0x20,0x20,0x6f,0x70,0x65,0x6e,0x2c,0x20,0x20,0x68,0x69,0x67,0x68,0x2c,
  0x20,0x20,0x6c,0x6f,0x77,0x2c,0x20,0x20,0x20,0x63,0x6c,0x6f,0x73,0x65,0xa,0x31,
  0x34,0x33,0x35,0x37,0x30,0x38,0x38,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x36,
  0x2e,0x39,0x30,0x20,0x31,0x32,0x36,0x2e,0x39,0x34,0x20,0x31,0x32,0x35,0x2e,0x39,
  0x39,0x20,0x31,0x32,0x36,0x2e,0x36,0x30,0xa,0x31,0x34,0x33,0x35,0x37,0x39,0x35,
  0x32,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x36,0x2e,0x36,0x39,0x20,0x31,0x32,
  0x36,0x2e,0x36,0x39,0x20,0x31,0x32,0x36,0x2e,0x36,0x39,0x20,0x31,0x32,0x36,0x2e,
  0x36,0x39,0xa,0x31,0x34,0x33,0x36,0x31,0x34,0x30,0x38,0x30,0x30,0x30,0x30,0x30,
  0x20,0x31,0x32,0x34,0x2e,0x38,0x35,0x20,0x31,0x32,0x36,0x2e,0x32,0x33,0x20,0x31,
  0x32,0x34,0x2e,0x38,0x35,0x20,0x31,0x32,0x36,0x2e,0x30,0x30,0xa,0x31,0x34,0x33,
  0x36,0x32,0x32,0x37,0x32,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x35,0x2e,0x38,
  0x39,0x20,0x31,0x32,0x36,0x2e,0x31,0x35,0x20,0x31,0x32,0x33,0x2e,0x37,0x37,0x20,
  0x31,0x32,0x35,0x2e,0x36,0x39,0xa,0x31,0x34,0x33,0x36,0x33,0x31,0x33,0x36,0x30,
  0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x34,0x2e,0x36,0x34,0x20,0x31,0x32,0x34,0x2e,
  0x36,0x34,0x20,0x31,0x32,0x32,0x2e,0x35,0x34,0x20,0x31,0x32,0x32,0x2e,0x35,0x34,
  0xa,0x31,0x34,0x33,0x36,0x34,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x20,0x31,
  0x32,0x33,0x2e,0x38,0x35,0x20,0x31,0x32,0x34,0x2e,0x30,0x36,0x20,0x31,0x31,0x39,
  0x2e,0x32,0x32,0x20,0x31,0x32,0x30,0x2e,0x30,0x37,0xa,0x31,0x34,0x33,0x36,0x34,
  0x38,0x36,0x34,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x31,0x2e,0x39,0x34,0x20,
  0x31,0x32,0x33,0x2e,0x38,0x35,0x20,0x31,0x32,0x31,0x2e,0x32,0x31,0x20,0x31,0x32,
  0x33,0x2e,0x32,0x38,0xa,0x31,0x34,0x33,0x36,0x37,0x34,0x35,0x36,0x30,0x30,0x30,
  0x30,0x30,0x20,0x31,0x32,0x35,0x2e,0x30,0x33,0x20,0x31,0x32,0x35,0x2e,0x37,0x36,
  0x20,0x31,0x32,0x34,0x2e,0x33,0x32,0x20,0x31,0x32,0x35,0x2e,0x36,0x36,0xa,0x31,
  0x34,0x33,0x36,0x38,0x33,0x32,0x30,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x36,
  0x2e,0x30,0x34,0x20,0x31,0x32,0x36,0x2e,0x33,0x37,0x20,0x31,0x32,0x35,0x2e,0x30,
  0x34,0x20,0x31,0x32,0x35,0x2e,0x36,0x31,0xa,0x31,0x34,0x33,0x36,0x39,0x31,0x38,
  0x34,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x35,0x2e,0x37,0x32,0x20,0x31,0x32,
  0x37,0x2e,0x31,0x35,0x20,0x31,0x32,0x35,0x2e,0x35,0x38,0x20,0x31,0x32,0x36,0x2e,
  0x38,0x32,0xa,0x31,0x34,0x33,0x37,0x30,0x30,0x34,0x38,0x30,0x30,0x30,0x30,0x30,
  0x20,0x31,0x32,0x37,0x2e,0x37,0x34,0x20,0x31,0x32,0x38,0x2e,0x35,0x37,0x20,0x31,
  0x32,0x37,0x2e,0x33,0x35,0x20,0x31,0x32,0x38,0x2e,0x35,0x31,0xa,0x31,0x34,0x33,
  0x37,0x30,0x39,0x31,0x32,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x39,0x2e,0x30,
  0x38,0x20,0x31,0x32,0x39,0x2e,0x36,0x32,0x20,0x31,0x32,0x38,0x2e,0x33,0x31,0x20,
  0x31,0x32,0x39,0x2e,0x36,0x32,0xa,0x31,0x34,0x33,0x37,0x33,0x35,0x30,0x34,0x30,
  0x30,0x30,0x30,0x30,0x20,0x31,0x33,0x30,0x2e,0x39,0x37,0x20,0x31,0x33,0x32,0x2e,
  0x39,0x37,0x20,0x31,0x33,0x30,0x2e,0x37,0x30,0x20,0x31,0x33,0x32,0x2e,0x30,0x37,
  0xa,0x31,0x34,0x33,0x37,0x34,0x33,0x36,0x38,0x30,0x30,0x30,0x30,0x30,0x20,0x31,
  0x33,0x32,0x2e,0x38,0x35,0x20,0x31,0x33,0x32,0x2e,0x39,0x32,0x20,0x31,0x33,0x30,
  0x2e,0x33,0x32,0x20,0x31,0x33,0x30,0x2e,0x37,0x35,0xa,0x31,0x34,0x33,0x37,0x35,
  0x32,0x33,0x32,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x31,0x2e,0x39,0x39,0x20,
  0x31,0x32,0x35,0x2e,0x35,0x30,0x20,0x31,0x32,0x31,0x2e,0x39,0x39,0x20,0x31,0x32,
  0x35,0x2e,0x32,0x32,0xa,0x31,0x34,0x33,0x37,0x36,0x30,0x39,0x36,0x30,0x30,0x30,
  0x30,0x30,0x20,0x31,0x32,0x36,0x2e,0x32,0x30,0x20,0x31,0x32,0x37,0x2e,0x30,0x39,
  0x20,0x31,0x32,0x35,0x2e,0x30,0x36,0x20,0x31,0x32,0x35,0x2e,0x31,0x36,0xa,0x31,
  0x34,0x33,0x37,0x36,0x39,0x36,0x30,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x35,
  0x2e,0x33,0x32,0x20,0x31,0x32,0x35,0x2e,0x37,0x34,0x20,0x31,0x32,0x33,0x2e,0x39,
  0x30,0x20,0x31,0x32,0x34,0x2e,0x35,0x30,0xa,0x31,0x34,0x33,0x37,0x39,0x35,0x35,
  0x32,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x33,0x2e,0x30,0x39,0x20,0x31,0x32,
  0x33,0x2e,0x36,0x31,0x20,0x31,0x32,0x32,0x2e,0x31,0x32,0x20,0x31,0x32,0x32,0x2e,
  0x37,0x37,0xa,0x31,0x34,0x33,0x38,0x30,0x34,0x31,0x36,0x30,0x30,0x30,0x30,0x30,
  0x20,0x31,0x32,0x33,0x2e,0x33,0x38,0x20,0x31,0x32,0x33,0x2e,0x39,0x31,0x20,0x31,
  0x32,0x32,0x2e,0x35,0x35,0x20,0x31,0x32,0x33,0x2e,0x33,0x38,0xa,0x31,0x34,0x33,
  0x38,0x31,0x32,0x38,0x30,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x33,0x2e,0x31,
  0x35,0x20,0x31,0x32,0x33,0x2e,0x35,0x30,0x20,0x31,0x32,0x32,0x2e,0x32,0x37,0x20,
  0x31,0x32,0x32,0x2e,0x39,0x39,0xa,0x31,0x34,0x33,0x38,0x32,0x31,0x34,0x34,0x30,
  0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x32,0x2e,0x33,0x32,0x20,0x31,0x32,0x32,0x2e,
  0x35,0x37,0x20,0x31,0x32,0x31,0x2e,0x37,0x31,0x20,0x31,0x32,0x32,0x2e,0x33,0x37,
  0xa,0x31,0x34,0x33,0x38,0x33,0x30,0x30,0x38,0x30,0x30,0x30,0x30,0x30,0x20,0x31,
  0x32,0x32,0x2e,0x36,0x30,0x20,0x31,0x32,0x32,0x2e,0x36,0x34,0x20,0x31,0x32,0x30,
  0x2e,0x39,0x31,0x20,0x31,0x32,0x31,0x2e,0x33,0x30,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // acme
  0x0,0x4,
  0x0,0x6,0x7a,0x35,
  0x0,0x61,
  0x0,0x63,0x0,0x6d,0x0,0x65,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/acme
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5e,0xa8,0xd9,0xd6,0x10,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_candlestickdata)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_candlestickdata)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_candlestickdata)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_candlestickdata)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_candlestickdata)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_candlestickdata)(); }
   } dummy;
}

==> qt5-charts-debuginfo-5.9.3-1.tar.xz: usr/src/debug/qt5-charts-5.9.3-1/examples/charts/candlestickchart/.rcc/qrc_candlestickdata.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-charts/qt5-charts-5.9.3-1.x86_64/src/qtcharts-opensource-src-5.9.3/examples/charts/candlestickchart/acme_data.txt
  0x0,0x0,0x3,0xec,
  0x23,
  0x20,0x41,0x63,0x6d,0x65,0x20,0x4c,0x74,0x64,0x20,0x48,0x69,0x73,0x74,0x6f,0x72,
  0x69,0x63,0x61,0x6c,0x20,0x44,0x61,0x74,0x61,0x20,0x28,0x4a,0x75,0x6c,0x79,0x20,
  0x32,0x30,0x31,0x35,0x29,0xa,0x23,0x20,0x74,0x69,0x6d,0x65,0x73,0x74,0x61,0x6d,
  0x70,0x2c,0x20,0x20,0x6f,0x70,0x65,0x6e,0x2c,0x20,0x20,0x68,0x69,0x67,0x68,0x2c,
  0x20,0x20,0x6c,0x6f,0x77,0x2c,0x20,0x20,0x20,0x63,0x6c,0x6f,0x73,0x65,0xa,0x31,
  0x34,0x33,0x35,0x37,0x30,0x38,0x38,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x36,
  0x2e,0x39,0x30,0x20,0x31,0x32,0x36,0x2e,0x39,0x34,0x20,0x31,0x32,0x35,0x2e,0x39,
  0x39,0x20,0x31,0x32,0x36,0x2e,0x36,0x30,0xa,0x31,0x34,0x33,0x35,0x37,0x39,0x35,
  0x32,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x36,0x2e,0x36,0x39,0x20,0x31,0x32,
  0x36,0x2e,0x36,0x39,0x20,0x31,0x32,0x36,0x2e,0x36,0x39,0x20,0x31,0x32,0x36,0x2e,
  0x36,0x39,0xa,0x31,0x34,0x33,0x36,0x31,0x34,0x30,0x38,0x30,0x30,0x30,0x30,0x30,
  0x20,0x31,0x32,0x34,0x2e,0x38,0x35,0x20,0x31,0x32,0x36,0x2e,0x32,0x33,0x20,0x31,
  0x32,0x34,0x2e,0x38,0x35,0x20,0x31,0x32,0x36,0x2e,0x30,0x30,0xa,0x31,0x34,0x33,
  0x36,0x32,0x32,0x37,0x32,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x35,0x2e,0x38,
  0x39,0x20,0x31,0x32,0x36,0x2e,0x31,0x35,0x20,0x31,0x32,0x33,0x2e,0x37,0x37,0x20,
  0x31,0x32,0x35,0x2e,0x36,0x39,0xa,0x31,0x34,0x33,0x36,0x33,0x31,0x33,0x36,0x30,
  0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x34,0x2e,0x36,0x34,0x20,0x31,0x32,0x34,0x2e,
  0x36,0x34,0x20,0x31,0x32,0x32,0x2e,0x35,0x34,0x20,0x31,0x32,0x32,0x2e,0x35,0x34,
  0xa,0x31,0x34,0x33,0x36,0x34,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x20,0x31,
  0x32,0x33,0x2e,0x38,0x35,0x20,0x31,0x32,0x34,0x2e,0x30,0x36,0x20,0x31,0x31,0x39,
  0x2e,0x32,0x32,0x20,0x31,0x32,0x30,0x2e,0x30,0x37,0xa,0x31,0x34,0x33,0x36,0x34,
  0x38,0x36,0x34,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x31,0x2e,0x39,0x34,0x20,
  0x31,0x32,0x33,0x2e,0x38,0x35,0x20,0x31,0x32,0x31,0x2e,0x32,0x31,0x20,0x31,0x32,
  0x33,0x2e,0x32,0x38,0xa,0x31,0x34,0x33,0x36,0x37,0x34,0x35,0x36,0x30,0x30,0x30,
  0x30,0x30,0x20,0x31,0x32,0x35,0x2e,0x30,0x33,0x20,0x31,0x32,0x35,0x2e,0x37,0x36,
  0x20,0x31,0x32,0x34,0x2e,0x33,0x32,0x20,0x31,0x32,0x35,0x2e,0x36,0x36,0xa,0x31,
  0x34,0x33,0x36,0x38,0x33,0x32,0x30,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x36,
  0x2e,0x30,0x34,0x20,0x31,0x32,0x36,0x2e,0x33,0x37,0x20,0x31,0x32,0x35,0x2e,0x30,
  0x34,0x20,0x31,0x32,0x35,0x2e,0x36,0x31,0xa,0x31,0x34,0x33,0x36,0x39,0x31,0x38,
  0x34,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x35,0x2e,0x37,0x32,0x20,0x31,0x32,
  0x37,0x2e,0x31,0x35,0x20,0x31,0x32,0x35,0x2e,0x35,0x38,0x20,0x31,0x32,0x36,0x2e,
  0x38,0x32,0xa,0x31,0x34,0x33,0x37,0x30,0x30,0x34,0x38,0x30,0x30,0x30,0x30,0x30,
  0x20,0x31,0x32,0x37,0x2e,0x37,0x34,0x20,0x31,0x32,0x38,0x2e,0x35,0x37,0x20,0x31,
  0x32,0x37,0x2e,0x33,0x35,0x20,0x31,0x32,0x38,0x2e,0x35,0x31,0xa,0x31,0x34,0x33,
  0x37,0x30,0x39,0x31,0x32,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x39,0x2e,0x30,
  0x38,0x20,0x31,0x32,0x39,0x2e,0x36,0x32,0x20,0x31,0x32,0x38,0x2e,0x33,0x31,0x20,
  0x31,0x32,0x39,0x2e,0x36,0x32,0xa,0x31,0x34,0x33,0x37,0x33,0x35,0x30,0x34,0x30,
  0x30,0x30,0x30,0x30,0x20,0x31,0x33,0x30,0x2e,0x39,0x37,0x20,0x31,0x33,0x32,0x2e,
  0x39,0x37,0x20,0x31,0x33,0x30,0x2e,0x37,0x30,0x20,0x31,0x33,0x32,0x2e,0x30,0x37,
  0xa,0x31,0x34,0x33,0x37,0x34,0x33,0x36,0x38,0x30,0x30,0x30,0x30,0x30,0x20,0x31,
  0x33,0x32,0x2e,0x38,0x35,0x20,0x31,0x33,0x32,0x2e,0x39,0x32,0x20,0x31,0x33,0x30,
  0x2e,0x33,0x32,0x20,0x31,0x33,0x30,0x2e,0x37,0x35,0xa,0x31,0x34,0x33,0x37,0x35,
  0x32,0x33,0x32,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x31,0x2e,0x39,0x39,0x20,
  0x31,0x32,0x35,0x2e,0x35,0x30,0x20,0x31,0x32,0x31,0x2e,0x39,0x39,0x20,0x31,0x32,
  0x35,0x2e,0x32,0x32,0xa,0x31,0x34,0x33,0x37,0x36,0x30,0x39,0x36,0x30,0x30,0x30,
  0x30,0x30,0x20,0x31,0x32,0x36,0x2e,0x32,0x30,0x20,0x31,0x32,0x37,0x2e,0x30,0x39,
  0x20,0x31,0x32,0x35,0x2e,0x30,0x36,0x20,0x31,0x32,0x35,0x2e,0x31,0x36,0xa,0x31,
  0x34,0x33,0x37,0x36,0x39,0x36,0x30,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x35,
  0x2e,0x33,0x32,0x20,0x31,0x32,0x35,0x2e,0x37,0x34,0x20,0x31,0x32,0x33,0x2e,0x39,
  0x30,0x20,0x31,0x32,0x34,0x2e,0x35,0x30,0xa,0x31,0x34,0x33,0x37,0x39,0x35,0x35,
  0x32,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x33,0x2e,0x30,0x39,0x20,0x31,0x32,
  0x33,0x2e,0x36,0x31,0x20,0x31,0x32,0x32,0x2e,0x31,0x32,0x20,0x31,0x32,0x32,0x2e,
  0x37,0x37,0xa,0x31,0x34,0x33,0x38,0x30,0x34,0x31,0x36,0x30,0x30,0x30,0x30,0x30,
  0x20,0x31,0x32,0x33,0x2e,0x33,0x38,0x20,0x31,0x32,0x33,0x2e,0x39,0x31,0x20,0x31,
  0x32,0x32,0x2e,0x35,0x35,0x20,0x31,0x32,0x33,0x2e,0x33,0x38,0xa,0x31,0x34,0x33,
  0x38,0x31,0x32,0x38,0x30,0x30,0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x33,0x2e,0x31,
  0x35,0x20,0x31,0x32,0x33,0x2e,0x35,0x30,0x20,0x31,0x32,0x32,0x2e,0x32,0x37,0x20,
  0x31,0x32,0x32,0x2e,0x39,0x39,0xa,0x31,0x34,0x33,0x38,0x32,0x31,0x34,0x34,0x30,
  0x30,0x30,0x30,0x30,0x20,0x31,0x32,0x32,0x2e,0x33,0x32,0x20,0x31,0x32,0x32,0x2e,
  0x35,0x37,0x20,0x31,0x32,0x31,0x2e,0x37,0x31,0x20,0x31,0x32,0x32,0x2e,0x33,0x37,
  0xa,0x31,0x34,0x33,0x38,0x33,0x30,0x30,0x38,0x30,0x30,0x30,0x30,0x30,0x20,0x31,
  0x32,0x32,0x2e,0x36,0x30,0x20,0x31,0x32,0x32,0x2e,0x36,0x34,0x20,0x31,0x32,0x30,
  0x2e,0x39,0x31,0x20,0x31,0x32,0x31,0x2e,0x33,0x30,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // acme
  0x0,0x4,
  0x0,0x6,0x7a,0x35,
  0x0,0x61,
  0x0,0x63,0x0,0x6d,0x0,0x65,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/acme
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x9a,0xa1,0x7f,0x20,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_candlestickdata)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_candlestickdata)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_candlestickdata)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_candlestickdata)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_candlestickdata)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_candlestickdata)(); }
   } dummy;
}
